summaryrefslogtreecommitdiff
path: root/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c')
-rw-r--r--nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c b/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
index ce9acd875..cfcdbede9 100644
--- a/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
+++ b/nuttx/configs/sure-pic32mx/src/pic32mx_buttons.c
@@ -125,17 +125,17 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
int i;
@@ -177,12 +177,12 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
@@ -125,17 +125,17 @@ static const uint8_t g_buttoncn[NUM_BUTTONS] =
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -177,12 +177,12 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -177,12 +177,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT